API Reference
=============

:class:`pymer4.models.Lmer`: Lmer
---------------------------------
Model class for estimating :code:`lme4` multi-level models in python

.. autoclass:: pymer4.models.Lmer
    :members:

:class:`pymer4.models.Lm`: Lm
-----------------------------
Model class for estimating standard regression models

.. autoclass:: pymer4.models.Lm
    :members:

:class:`pymer4.models.Lm2`: Lm2
-------------------------------
Model class for estimating multi-level models in python using the summary-statistics approach

.. autoclass:: pymer4.models.Lm2
    :members:

:mod:`pymer4.simulate`: Simulation Functions
--------------------------------------------
Functions for generating data for use with various model types

.. automodule:: pymer4.simulate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pymer4.stats`: Statistics Functions
-----------------------------------------
General purpose functions for various parametric and non-parametric statistical routines

.. automodule:: pymer4.stats
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pymer4.utils`: Utility Functions
--------------------------------------
Miscellaneous helper functions

.. automodule:: pymer4.utils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pymer4.io`: Save/Load Functions
-------------------------------------
Functions for persisting models to disk

.. automodule:: pymer4.io
    :members:
    :undoc-members:
    :show-inheritance:
